Documentation
¶
Overview ¶
Package gaesecrets implements storage of secret blobs on top of datastore.
It is not super secure, but we have what we have: there's no other better mechanism to persistently store non-static secrets on GAE.
All secrets are global (live in default GAE namespace).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
NoAutogenerate bool // if true, GetSecret will NOT generate secrets
SecretLen int // length of generated secrets, 32 bytes default
Prefix string // optional prefix for entity keys to namespace them
Entropy io.Reader // source of random numbers, crypto rand by default
}
Config can be used to tweak parameters of the store. It is fine to use default values.
Source Files
¶
- gaesecrets.go
Click to show internal directories.
Click to hide internal directories.