Documentation
¶
Overview ¶
Package gaesettings implements settings.Storage interface on top of GAE datastore.
See github.com/luci/luci-go/server/settings for more details.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Storage ¶
type Storage struct{}
Storage knows how to store JSON blobs with settings in the datastore.
It implements server/settings.EventualConsistentStorage interface.
func (Storage) FetchAllSettings ¶
FetchAllSettings fetches all latest settings at once.
func (Storage) GetConsistencyTime ¶
GetConsistencyTime returns "last modification time" + "expiration period".
It indicates moment in time when last setting change is fully propagated to all instances.
Returns zero time if there are no settings stored.
Source Files
¶
- gaesettings.go
Click to show internal directories.
Click to hide internal directories.