Documentation
¶
Overview ¶
Package buildbucket is a generated protocol buffer package.
It is generated from these files:
github.com/luci/luci-go/buildbucket/client/cmd/buildbucket/proto/project_config.proto
It has these top-level messages:
Acl AclSet Swarming Bucket BuildbucketCfg
Index ¶
- Variables
- type Acl
- type AclSet
- type Acl_Role
- type Bucket
- type BuildbucketCfg
- type Swarming
- func (*Swarming) Descriptor() ([]byte, []int)
- func (m *Swarming) GetBuilderDefaults() *Swarming_Builder
- func (m *Swarming) GetBuilders() []*Swarming_Builder
- func (m *Swarming) GetHostname() string
- func (m *Swarming) GetTaskTemplateCanaryPercentage() uint32
- func (m *Swarming) GetUrlFormat() string
- func (*Swarming) ProtoMessage()
- func (m *Swarming) Reset()
- func (m *Swarming) String() string
- type Swarming_Builder
- func (*Swarming_Builder) Descriptor() ([]byte, []int)
- func (m *Swarming_Builder) GetCaches() []*Swarming_Builder_CacheEntry
- func (m *Swarming_Builder) GetCategory() string
- func (m *Swarming_Builder) GetCipdPackages() []*Swarming_Builder_CipdPackage
- func (m *Swarming_Builder) GetDimensions() []string
- func (m *Swarming_Builder) GetExecutionTimeoutSecs() uint32
- func (m *Swarming_Builder) GetName() string
- func (m *Swarming_Builder) GetPriority() uint32
- func (m *Swarming_Builder) GetRecipe() *Swarming_Recipe
- func (m *Swarming_Builder) GetSwarmingTags() []string
- func (*Swarming_Builder) ProtoMessage()
- func (m *Swarming_Builder) Reset()
- func (m *Swarming_Builder) String() string
- type Swarming_Builder_CacheEntry
- func (*Swarming_Builder_CacheEntry) Descriptor() ([]byte, []int)
- func (m *Swarming_Builder_CacheEntry) GetName() string
- func (m *Swarming_Builder_CacheEntry) GetPath() string
- func (*Swarming_Builder_CacheEntry) ProtoMessage()
- func (m *Swarming_Builder_CacheEntry) Reset()
- func (m *Swarming_Builder_CacheEntry) String() string
- type Swarming_Builder_CipdPackage
- func (*Swarming_Builder_CipdPackage) Descriptor() ([]byte, []int)
- func (m *Swarming_Builder_CipdPackage) GetPackageName() string
- func (m *Swarming_Builder_CipdPackage) GetPath() string
- func (m *Swarming_Builder_CipdPackage) GetVersion() string
- func (*Swarming_Builder_CipdPackage) ProtoMessage()
- func (m *Swarming_Builder_CipdPackage) Reset()
- func (m *Swarming_Builder_CipdPackage) String() string
- type Swarming_Recipe
- func (*Swarming_Recipe) Descriptor() ([]byte, []int)
- func (m *Swarming_Recipe) GetName() string
- func (m *Swarming_Recipe) GetProperties() []string
- func (m *Swarming_Recipe) GetPropertiesJ() []string
- func (m *Swarming_Recipe) GetRepository() string
- func (*Swarming_Recipe) ProtoMessage()
- func (m *Swarming_Recipe) Reset()
- func (m *Swarming_Recipe) String() string
Constants ¶
This section is empty.
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Acl ¶
type Acl struct {
// Role denotes a list of actions that an identity can perform.
Role *Acl_Role `protobuf:"varint,1,opt,name=role,enum=buildbucket.Acl_Role" json:"role,omitempty"`
// Name of the group defined in the auth service.
Group *string `protobuf:"bytes,2,opt,name=group" json:"group,omitempty"`
// An email address or a full identity string "kind:name". See auth service
// on kinds of identities. Anonymous users are "anonymous:anonymous".
// Either identity or group must be present, not both.
Identity *string `protobuf:"bytes,3,opt,name=identity" json:"identity,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
A single access control rule.
type AclSet ¶
type AclSet struct {
// A name of the ACL set. Required. Must match regex '^[a-z0-9_]+$'.
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// List of access control rules.
// The order does not matter.
Acls []*Acl `protobuf:"bytes,2,rep,name=acls" json:"acls,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
A set of Acl messages. Can be referenced in a bucket by name.
type Bucket ¶
type Bucket struct {
// Name of the bucket. Names are unique within one instance of buildbucket.
// If another project already uses this name, a config will be rejected.
// Name reservation is first-come first-serve.
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// List of access control rules for the bucket.
// The order does not matter.
Acls []*Acl `protobuf:"bytes,2,rep,name=acls" json:"acls,omitempty"`
// A list of ACL set names. Each ACL in each referenced ACL set will be
// included in this bucket.
// The order does not matter.
AclSets []string `protobuf:"bytes,4,rep,name=acl_sets,json=aclSets" json:"acl_sets,omitempty"`
// Buildbucket-swarming integration.
Swarming *Swarming `protobuf:"bytes,3,opt,name=swarming" json:"swarming,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Defines one bucket in buildbucket.cfg
type BuildbucketCfg ¶
type BuildbucketCfg struct {
// All buckets defined for this project.
Buckets []*Bucket `protobuf:"bytes,1,rep,name=buckets" json:"buckets,omitempty"`
// A list of ACL sets. Names must be unique.
AclSets []*AclSet `protobuf:"bytes,2,rep,name=acl_sets,json=aclSets" json:"acl_sets,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Schema of buildbucket.cfg file, a project config.
func (*BuildbucketCfg) Descriptor ¶
func (*BuildbucketCfg) Descriptor() ([]byte, []int)
func (*BuildbucketCfg) GetAclSets ¶
func (m *BuildbucketCfg) GetAclSets() []*AclSet
func (*BuildbucketCfg) GetBuckets ¶
func (m *BuildbucketCfg) GetBuckets() []*Bucket
func (*BuildbucketCfg) ProtoMessage ¶
func (*BuildbucketCfg) ProtoMessage()
func (*BuildbucketCfg) Reset ¶
func (m *BuildbucketCfg) Reset()
func (*BuildbucketCfg) String ¶
func (m *BuildbucketCfg) String() string
type Swarming ¶
type Swarming struct {
// Hostname of the swarming instance, e.g. "chromium-swarm.appspot.com".
Hostname *string `protobuf:"bytes,1,opt,name=hostname" json:"hostname,omitempty"`
// Used to generate a URL for Build, may contain parameters
// {swarming_hostname}, {task_id}, {bucket} and {builder}. Defaults to:
// https://{swarming_hostname}/user/task/{task_id}
UrlFormat *string `protobuf:"bytes,2,opt,name=url_format,json=urlFormat" json:"url_format,omitempty"`
// Defines default values for builders.
BuilderDefaults *Swarming_Builder `protobuf:"bytes,3,opt,name=builder_defaults,json=builderDefaults" json:"builder_defaults,omitempty"`
// Configuration for each builder.
// Swarming tasks are created only for builds for builders that are not
// explicitly specified.
Builders []*Swarming_Builder `protobuf:"bytes,4,rep,name=builders" json:"builders,omitempty"`
// Percentage of builds that should use a canary swarming task template.
// A value from 0 to 100.
TaskTemplateCanaryPercentage *uint32 `` /* 143-byte string literal not displayed */
XXX_unrecognized []byte `json:"-"`
}
Configuration of buildbucket-swarming integration for one bucket.
func (*Swarming) GetBuilderDefaults ¶
func (m *Swarming) GetBuilderDefaults() *Swarming_Builder
func (*Swarming) GetBuilders ¶
func (m *Swarming) GetBuilders() []*Swarming_Builder
func (*Swarming) GetTaskTemplateCanaryPercentage ¶
type Swarming_Builder ¶
type Swarming_Builder struct {
// Name of the builder. Will be propagated to "builder" build tag and
// "buildername" recipe property.
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// Builder category. Will be used for visual grouping, for example in Code Review.
Category *string `protobuf:"bytes,6,opt,name=category" json:"category,omitempty"`
// Will be become to swarming task tags.
// Each tag will end up in "swarming_tag" buildbucket tag, for example
// "swarming_tag:builder:release"
SwarmingTags []string `protobuf:"bytes,2,rep,name=swarming_tags,json=swarmingTags" json:"swarming_tags,omitempty"`
// Colon-delimited key-value pair of task dimensions.
//
// If value is not specified ("<key>:"), then it excludes a default value.
Dimensions []string `protobuf:"bytes,3,rep,name=dimensions" json:"dimensions,omitempty"`
// CIPD packages to install on the builder.
CipdPackages []*Swarming_Builder_CipdPackage `protobuf:"bytes,8,rep,name=cipd_packages,json=cipdPackages" json:"cipd_packages,omitempty"`
// Specifies that a recipe to run.
Recipe *Swarming_Recipe `protobuf:"bytes,4,opt,name=recipe" json:"recipe,omitempty"`
// Swarming task priority.
Priority *uint32 `protobuf:"varint,5,opt,name=priority" json:"priority,omitempty"`
// Maximum build execution time. Not to be confused with pending time.
ExecutionTimeoutSecs *uint32 `protobuf:"varint,7,opt,name=execution_timeout_secs,json=executionTimeoutSecs" json:"execution_timeout_secs,omitempty"`
// Caches that should be present on the bot.
Caches []*Swarming_Builder_CacheEntry `protobuf:"bytes,9,rep,name=caches" json:"caches,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
A builder has a name, a category and specifies what should happen if a build is scheduled to that builder.
SECURITY WARNING: if adding more fields to this message, keep in mind that a user that has permissions to schedule a build to the bucket, can override this config.
func (*Swarming_Builder) Descriptor ¶
func (*Swarming_Builder) Descriptor() ([]byte, []int)
func (*Swarming_Builder) GetCaches ¶
func (m *Swarming_Builder) GetCaches() []*Swarming_Builder_CacheEntry
func (*Swarming_Builder) GetCategory ¶
func (m *Swarming_Builder) GetCategory() string
func (*Swarming_Builder) GetCipdPackages ¶
func (m *Swarming_Builder) GetCipdPackages() []*Swarming_Builder_CipdPackage
func (*Swarming_Builder) GetDimensions ¶
func (m *Swarming_Builder) GetDimensions() []string
func (*Swarming_Builder) GetExecutionTimeoutSecs ¶
func (m *Swarming_Builder) GetExecutionTimeoutSecs() uint32
func (*Swarming_Builder) GetName ¶
func (m *Swarming_Builder) GetName() string
func (*Swarming_Builder) GetPriority ¶
func (m *Swarming_Builder) GetPriority() uint32
func (*Swarming_Builder) GetRecipe ¶
func (m *Swarming_Builder) GetRecipe() *Swarming_Recipe
func (*Swarming_Builder) GetSwarmingTags ¶
func (m *Swarming_Builder) GetSwarmingTags() []string
func (*Swarming_Builder) ProtoMessage ¶
func (*Swarming_Builder) ProtoMessage()
func (*Swarming_Builder) Reset ¶
func (m *Swarming_Builder) Reset()
func (*Swarming_Builder) String ¶
func (m *Swarming_Builder) String() string
type Swarming_Builder_CacheEntry ¶
type Swarming_Builder_CacheEntry struct {
// Unique name of the cache. Required. Length is limited to 4096.
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// Relative path to the directory that will be linked to the named cache.
// Required.
// A path cannot be shared among multiple caches or CIPD installations.
// A task will fail if a file/dir with the same name already exists.
Path *string `protobuf:"bytes,2,opt,name=path" json:"path,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Describes a named cache that should be present on the bot. See also https://github.com/luci/luci-py/blob/3a2941345cf011a96bcd83d76328395323245bb5/appengine/swarming/swarming_rpcs.py#L166
func (*Swarming_Builder_CacheEntry) Descriptor ¶
func (*Swarming_Builder_CacheEntry) Descriptor() ([]byte, []int)
func (*Swarming_Builder_CacheEntry) GetName ¶
func (m *Swarming_Builder_CacheEntry) GetName() string
func (*Swarming_Builder_CacheEntry) GetPath ¶
func (m *Swarming_Builder_CacheEntry) GetPath() string
func (*Swarming_Builder_CacheEntry) ProtoMessage ¶
func (*Swarming_Builder_CacheEntry) ProtoMessage()
func (*Swarming_Builder_CacheEntry) Reset ¶
func (m *Swarming_Builder_CacheEntry) Reset()
func (*Swarming_Builder_CacheEntry) String ¶
func (m *Swarming_Builder_CacheEntry) String() string
type Swarming_Builder_CipdPackage ¶
type Swarming_Builder_CipdPackage struct {
// A template of a full CIPD package name, e.g
// "infra/tools/authutil/${platform}". This can be parametrized using
// ${platform} and ${os_ver} parameters, where ${platform} will be
// expanded into "<os>-<architecture>" and ${os_ver} will be expanded to
// OS version name.
PackageName *string `protobuf:"bytes,1,opt,name=package_name,json=packageName" json:"package_name,omitempty"`
// Path to dir, relative to the task working dir, where to install the
// package. The path cannot be empty or start with a slash.
Path *string `protobuf:"bytes,2,opt,name=path" json:"path,omitempty"`
// Valid package version for all packages matched by package name.
Version *string `protobuf:"bytes,3,opt,name=version" json:"version,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Swarming_Builder_CipdPackage) Descriptor ¶
func (*Swarming_Builder_CipdPackage) Descriptor() ([]byte, []int)
func (*Swarming_Builder_CipdPackage) GetPackageName ¶
func (m *Swarming_Builder_CipdPackage) GetPackageName() string
func (*Swarming_Builder_CipdPackage) GetPath ¶
func (m *Swarming_Builder_CipdPackage) GetPath() string
func (*Swarming_Builder_CipdPackage) GetVersion ¶
func (m *Swarming_Builder_CipdPackage) GetVersion() string
func (*Swarming_Builder_CipdPackage) ProtoMessage ¶
func (*Swarming_Builder_CipdPackage) ProtoMessage()
func (*Swarming_Builder_CipdPackage) Reset ¶
func (m *Swarming_Builder_CipdPackage) Reset()
func (*Swarming_Builder_CipdPackage) String ¶
func (m *Swarming_Builder_CipdPackage) String() string
type Swarming_Recipe ¶
type Swarming_Recipe struct {
// Repository URL of the recipe package.
Repository *string `protobuf:"bytes,1,opt,name=repository" json:"repository,omitempty"`
// Name of the recipe to run.
Name *string `protobuf:"bytes,2,opt,name=name" json:"name,omitempty"`
// colon-separated build properties to set.
// A property can be overriden by "properties" build parameter.
//
// Use this field for string properties and use properties_j for other
// types.
Properties []string `protobuf:"bytes,3,rep,name=properties" json:"properties,omitempty"`
// Same as properties, but the value must valid JSON. For example
// properties_j: "a:1"
// means property a is a number 1, not string "1".
//
// If null, it means no property must be defined. In particular, it removes
// a default value for the property, if any.
//
// Fields properties and properties_j can be used together, but cannot both
// specify values for same property.
PropertiesJ []string `protobuf:"bytes,4,rep,name=properties_j,json=propertiesJ" json:"properties_j,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Swarming_Recipe) Descriptor ¶
func (*Swarming_Recipe) Descriptor() ([]byte, []int)
func (*Swarming_Recipe) GetName ¶
func (m *Swarming_Recipe) GetName() string
func (*Swarming_Recipe) GetProperties ¶
func (m *Swarming_Recipe) GetProperties() []string
func (*Swarming_Recipe) GetPropertiesJ ¶
func (m *Swarming_Recipe) GetPropertiesJ() []string
func (*Swarming_Recipe) GetRepository ¶
func (m *Swarming_Recipe) GetRepository() string
func (*Swarming_Recipe) ProtoMessage ¶
func (*Swarming_Recipe) ProtoMessage()
func (*Swarming_Recipe) Reset ¶
func (m *Swarming_Recipe) Reset()
func (*Swarming_Recipe) String ¶
func (m *Swarming_Recipe) String() string
Source Files
¶
- gen.go
- project_config.pb.go