Documentation
¶
Overview ¶
Package logdog is a generated protocol buffer package.
It is generated from these files:
github.com/luci/luci-go/logdog/api/endpoints/coordinator/admin/v1/admin.proto
It has these top-level messages:
SetConfigRequest
Package logdog contains Version 1 of the LogDog Coordinator service interface.
The package name here must match the protobuf package name, as the generated files will reside in the same directory.
Index ¶
- func FileDescriptorSet() *descriptor.FileDescriptorSet
- func RegisterAdminServer(s prpc.Registrar, srv AdminServer)
- type AdminClient
- type AdminServer
- type DecoratedAdmin
- type SetConfigRequest
- func (*SetConfigRequest) Descriptor() ([]byte, []int)
- func (m *SetConfigRequest) GetConfigPath() string
- func (m *SetConfigRequest) GetConfigServiceUrl() string
- func (m *SetConfigRequest) GetConfigSet() string
- func (m *SetConfigRequest) GetStorageServiceAccountJson() []byte
- func (*SetConfigRequest) ProtoMessage()
- func (m *SetConfigRequest) Reset()
- func (m *SetConfigRequest) String() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FileDescriptorSet ¶
func FileDescriptorSet() *descriptor.FileDescriptorSet
FileDescriptorSet returns a descriptor set for this proto package, which includes all defined services, and all transitive dependencies.
Will not return nil.
Do NOT modify the returned descriptor.
func RegisterAdminServer ¶
func RegisterAdminServer(s prpc.Registrar, srv AdminServer)
Types ¶
type AdminClient ¶
type AdminClient interface {
// SetConfig loads the supplied configuration into a config.GlobalConfig
// instance.
SetConfig(ctx context.Context, in *SetConfigRequest, opts ...grpc.CallOption) (*google_protobuf.Empty, error)
}
func NewAdminClient ¶
func NewAdminClient(cc *grpc.ClientConn) AdminClient
func NewAdminPRPCClient ¶
func NewAdminPRPCClient(client *prpc.Client) AdminClient
type AdminServer ¶
type AdminServer interface {
// SetConfig loads the supplied configuration into a config.GlobalConfig
// instance.
SetConfig(context.Context, *SetConfigRequest) (*google_protobuf.Empty, error)
}
type DecoratedAdmin ¶
type DecoratedAdmin struct {
// Service is the service to decorate.
Service AdminServer
// Prelude is called for each method before forwarding the call to Service.
// If Prelude returns an error, then the call is skipped and the error is
// processed via the Postlude (if one is defined), or it is returned directly.
Prelude func(c context.Context, methodName string, req proto.Message) (context.Context, error)
// Postlude is called for each method after Service has processed the call, or
// after the Prelude has returned an error. This takes the the Service's
// response proto (which may be nil) and/or any error. The decorated
// service will return the response (possibly mutated) and error that Postlude
// returns.
Postlude func(c context.Context, methodName string, rsp proto.Message, err error) error
}
func (*DecoratedAdmin) SetConfig ¶
func (s *DecoratedAdmin) SetConfig(c context.Context, req *SetConfigRequest) (rsp *google_protobuf.Empty, err error)
type SetConfigRequest ¶
type SetConfigRequest struct {
// ConfigServiceURL is the API URL of the base "luci-config" service. If
// empty, the defualt service URL will be used.
ConfigServiceUrl string `protobuf:"bytes,1,opt,name=config_service_url,json=configServiceUrl" json:"config_service_url,omitempty"`
// ConfigSet is the name of the configuration set to load from.
ConfigSet string `protobuf:"bytes,2,opt,name=config_set,json=configSet" json:"config_set,omitempty"`
// ConfigPath is the path of the text-serialized configuration protobuf.
ConfigPath string `protobuf:"bytes,3,opt,name=config_path,json=configPath" json:"config_path,omitempty"`
// If not empty, is the service account JSON file data that will be used for
// Storage access.
//
// TODO(dnj): Remove this option once Cloud BigTable has cross-project ACLs.
StorageServiceAccountJson []byte `` /* 142-byte string literal not displayed */
}
GlobalConfig is the LogDog Coordinator global configuration.
This is intended to act as an entry point. The majority of the configuration will be stored in a "luci-config" service Config protobuf.
func (*SetConfigRequest) Descriptor ¶
func (*SetConfigRequest) Descriptor() ([]byte, []int)
func (*SetConfigRequest) GetConfigPath ¶
func (m *SetConfigRequest) GetConfigPath() string
func (*SetConfigRequest) GetConfigServiceUrl ¶
func (m *SetConfigRequest) GetConfigServiceUrl() string
func (*SetConfigRequest) GetConfigSet ¶
func (m *SetConfigRequest) GetConfigSet() string
func (*SetConfigRequest) GetStorageServiceAccountJson ¶
func (m *SetConfigRequest) GetStorageServiceAccountJson() []byte
func (*SetConfigRequest) ProtoMessage ¶
func (*SetConfigRequest) ProtoMessage()
func (*SetConfigRequest) Reset ¶
func (m *SetConfigRequest) Reset()
func (*SetConfigRequest) String ¶
func (m *SetConfigRequest) String() string
Source Files
¶
- admin.pb.go
- adminserver_dec.go
- gen.go
- pb.discovery.go