Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ProjectBoundMessage ¶
type ProjectBoundMessage interface {
// GetMessageProject returns the Project to which this message is bound.
GetMessageProject() string
}
ProjectBoundMessage describes an object that is bound to a Project namespace.
This is intended to be implemented by project-bound protobufs.
Source Files
¶
- projectBoundMessage.go
- util.go
Click to show internal directories.
Click to hide internal directories.