Documentation
¶
Index ¶
- type CreateArchiveTask
- func (m *CreateArchiveTask) HighPriority() bool
- func (m *CreateArchiveTask) ProcessAfter() time.Time
- func (m *CreateArchiveTask) RollForward(c context.Context) ([]tumble.Mutation, error)
- func (m *CreateArchiveTask) Root(c context.Context) *ds.Key
- func (m *CreateArchiveTask) TaskName(c context.Context) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateArchiveTask ¶
type CreateArchiveTask struct {
// ID is the hash ID of the LogStream whose archive task is being created.
//
// Note that the task will apply to the LogStreamState, not the stream
// entity itself.
ID coordinator.HashID
// SettleDelay is the settle delay (see ArchivalParams).
SettleDelay time.Duration
// CompletePeriod is the complete period to use (see ArchivalParams).
CompletePeriod time.Duration
// Expiration is the delay applied to the archive task via ProcessAfter.
Expiration time.Time
}
CreateArchiveTask is a tumble Mutation that registers an archive task.
It is a named mutation.
func (*CreateArchiveTask) HighPriority ¶
func (m *CreateArchiveTask) HighPriority() bool
HighPriority implements tumble.DelayedMutation.
func (*CreateArchiveTask) ProcessAfter ¶
func (m *CreateArchiveTask) ProcessAfter() time.Time
ProcessAfter implements tumble.DelayedMutation.
func (*CreateArchiveTask) RollForward ¶
RollForward implements tumble.DelayedMutation.
func (*CreateArchiveTask) Root ¶
func (m *CreateArchiveTask) Root(c context.Context) *ds.Key
Root implements tumble.DelayedMutation.
func (*CreateArchiveTask) TaskName ¶
func (m *CreateArchiveTask) TaskName(c context.Context) string
TaskName returns the task's name, which is derived from its log stream ID.
Source Files
¶
- createArchiveTask.go
Click to show internal directories.
Click to hide internal directories.