Documentation
¶
Overview ¶
Package bootstrap handles Butler-side bootstrapping functionality.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Environment ¶
type Environment struct {
// CoordinatorHost is the coordinator host name, or empty string if we are
// not outputting to a Coordinator.
CoordinatorHost string
// Project is the project name. If not empty, this will be exported to
// subprocesses.
Project cfgtypes.ProjectName
// Prefix is the prefix name. If not empty, this will be exported to
// subprocesses.
Prefix types.StreamName
// StreamServerURI is the streamserver URI. If not empty, this will be
// exported to subprocesses.
StreamServerURI string
}
Environment is the set of configuration parameters for the bootstrap.
func (*Environment) Augment ¶
func (e *Environment) Augment(base environ.Env)
Augment augments the supplied base environment with LogDog Butler bootstrap parameters.
Source Files
¶
- env.go
Click to show internal directories.
Click to hide internal directories.