Documentation
¶
Overview ¶
Package pubsub implements the "pubsub" Output.
The "pubsub" (Google Cloud Pub/Sub) Output publishes ButlerLogBundle protobufs to a Google Cloud Pub/Sub topic using the protocol defined in:
github.com/luci/luci-go/common/logdog/butlerproto
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// Topic is the Pub/Sub topic to publish to.
Topic Topic
// Secret, if not nil, is the prefix secret to attach to each outgoing bundle.
Secret types.PrefixSecret
// Compress, if true, enables zlib compression.
Compress bool
// Track, if true, tracks all log entries that have been successfully
// submitted.
Track bool
// RPCTimeout is the timeout to apply to an individual RPC.
RPCTimeout time.Duration
}
Config is a configuration structure for Pub/Sub output.
Source Files
¶
- doc.go
- pubsubOutput.go
Click to show internal directories.
Click to hide internal directories.