Documentation
¶
Overview ¶
Package protocol is a generated protocol buffer package.
It is generated from these files:
github.com/luci/luci-go/server/auth/service/protocol/replication.proto
It has these top-level messages:
ServiceLinkTicket ServiceLinkRequest ServiceLinkResponse AuthGroup AuthIPWhitelist AuthIPWhitelistAssignment AuthDB AuthDBRevision ChangeNotification ReplicationPushRequest ReplicationPushResponse
Index ¶
- Variables
- type AuthDB
- func (*AuthDB) Descriptor() ([]byte, []int)
- func (m *AuthDB) GetGroups() []*AuthGroup
- func (m *AuthDB) GetIpWhitelistAssignments() []*AuthIPWhitelistAssignment
- func (m *AuthDB) GetIpWhitelists() []*AuthIPWhitelist
- func (m *AuthDB) GetOauthAdditionalClientIds() []string
- func (m *AuthDB) GetOauthClientId() string
- func (m *AuthDB) GetOauthClientSecret() string
- func (m *AuthDB) GetTokenServerUrl() string
- func (*AuthDB) ProtoMessage()
- func (m *AuthDB) Reset()
- func (m *AuthDB) String() string
- type AuthDBRevision
- func (*AuthDBRevision) Descriptor() ([]byte, []int)
- func (m *AuthDBRevision) GetAuthDbRev() int64
- func (m *AuthDBRevision) GetModifiedTs() int64
- func (m *AuthDBRevision) GetPrimaryId() string
- func (*AuthDBRevision) ProtoMessage()
- func (m *AuthDBRevision) Reset()
- func (m *AuthDBRevision) String() string
- type AuthGroup
- func (*AuthGroup) Descriptor() ([]byte, []int)
- func (m *AuthGroup) GetCreatedBy() string
- func (m *AuthGroup) GetCreatedTs() int64
- func (m *AuthGroup) GetDescription() string
- func (m *AuthGroup) GetGlobs() []string
- func (m *AuthGroup) GetMembers() []string
- func (m *AuthGroup) GetModifiedBy() string
- func (m *AuthGroup) GetModifiedTs() int64
- func (m *AuthGroup) GetName() string
- func (m *AuthGroup) GetNested() []string
- func (m *AuthGroup) GetOwners() string
- func (*AuthGroup) ProtoMessage()
- func (m *AuthGroup) Reset()
- func (m *AuthGroup) String() string
- type AuthIPWhitelist
- func (*AuthIPWhitelist) Descriptor() ([]byte, []int)
- func (m *AuthIPWhitelist) GetCreatedBy() string
- func (m *AuthIPWhitelist) GetCreatedTs() int64
- func (m *AuthIPWhitelist) GetDescription() string
- func (m *AuthIPWhitelist) GetModifiedBy() string
- func (m *AuthIPWhitelist) GetModifiedTs() int64
- func (m *AuthIPWhitelist) GetName() string
- func (m *AuthIPWhitelist) GetSubnets() []string
- func (*AuthIPWhitelist) ProtoMessage()
- func (m *AuthIPWhitelist) Reset()
- func (m *AuthIPWhitelist) String() string
- type AuthIPWhitelistAssignment
- func (*AuthIPWhitelistAssignment) Descriptor() ([]byte, []int)
- func (m *AuthIPWhitelistAssignment) GetComment() string
- func (m *AuthIPWhitelistAssignment) GetCreatedBy() string
- func (m *AuthIPWhitelistAssignment) GetCreatedTs() int64
- func (m *AuthIPWhitelistAssignment) GetIdentity() string
- func (m *AuthIPWhitelistAssignment) GetIpWhitelist() string
- func (*AuthIPWhitelistAssignment) ProtoMessage()
- func (m *AuthIPWhitelistAssignment) Reset()
- func (m *AuthIPWhitelistAssignment) String() string
- type ChangeNotification
- type ReplicationPushRequest
- func (*ReplicationPushRequest) Descriptor() ([]byte, []int)
- func (m *ReplicationPushRequest) GetAuthCodeVersion() string
- func (m *ReplicationPushRequest) GetAuthDb() *AuthDB
- func (m *ReplicationPushRequest) GetRevision() *AuthDBRevision
- func (*ReplicationPushRequest) ProtoMessage()
- func (m *ReplicationPushRequest) Reset()
- func (m *ReplicationPushRequest) String() string
- type ReplicationPushResponse
- func (*ReplicationPushResponse) Descriptor() ([]byte, []int)
- func (m *ReplicationPushResponse) GetAuthCodeVersion() string
- func (m *ReplicationPushResponse) GetCurrentRevision() *AuthDBRevision
- func (m *ReplicationPushResponse) GetErrorCode() ReplicationPushResponse_ErrorCode
- func (m *ReplicationPushResponse) GetStatus() ReplicationPushResponse_Status
- func (*ReplicationPushResponse) ProtoMessage()
- func (m *ReplicationPushResponse) Reset()
- func (m *ReplicationPushResponse) String() string
- type ReplicationPushResponse_ErrorCode
- type ReplicationPushResponse_Status
- type ServiceLinkRequest
- func (*ServiceLinkRequest) Descriptor() ([]byte, []int)
- func (m *ServiceLinkRequest) GetInitiatedBy() string
- func (m *ServiceLinkRequest) GetReplicaUrl() string
- func (m *ServiceLinkRequest) GetTicket() []byte
- func (*ServiceLinkRequest) ProtoMessage()
- func (m *ServiceLinkRequest) Reset()
- func (m *ServiceLinkRequest) String() string
- type ServiceLinkResponse
- type ServiceLinkResponse_Status
- type ServiceLinkTicket
- func (*ServiceLinkTicket) Descriptor() ([]byte, []int)
- func (m *ServiceLinkTicket) GetGeneratedBy() string
- func (m *ServiceLinkTicket) GetPrimaryId() string
- func (m *ServiceLinkTicket) GetPrimaryUrl() string
- func (m *ServiceLinkTicket) GetTicket() []byte
- func (*ServiceLinkTicket) ProtoMessage()
- func (m *ServiceLinkTicket) Reset()
- func (m *ServiceLinkTicket) String() string
Constants ¶
This section is empty.
Variables ¶
var ReplicationPushResponse_ErrorCode_name = map[int32]string{
1: "NOT_A_REPLICA",
2: "FORBIDDEN",
3: "MISSING_SIGNATURE",
4: "BAD_SIGNATURE",
5: "BAD_REQUEST",
}
var ReplicationPushResponse_ErrorCode_value = map[string]int32{
"NOT_A_REPLICA": 1,
"FORBIDDEN": 2,
"MISSING_SIGNATURE": 3,
"BAD_SIGNATURE": 4,
"BAD_REQUEST": 5,
}
var ReplicationPushResponse_Status_name = map[int32]string{
0: "APPLIED",
1: "SKIPPED",
2: "TRANSIENT_ERROR",
3: "FATAL_ERROR",
}
var ReplicationPushResponse_Status_value = map[string]int32{
"APPLIED": 0,
"SKIPPED": 1,
"TRANSIENT_ERROR": 2,
"FATAL_ERROR": 3,
}
Functions ¶
This section is empty.
Types ¶
type AuthDB ¶
type AuthDB struct {
// OAuth2 client_id to use to mint new OAuth2 tokens.
OauthClientId *string `protobuf:"bytes,1,req,name=oauth_client_id,json=oauthClientId" json:"oauth_client_id,omitempty"`
// OAuth2 client secret. Not so secret really, since it's passed to clients.
OauthClientSecret *string `protobuf:"bytes,2,req,name=oauth_client_secret,json=oauthClientSecret" json:"oauth_client_secret,omitempty"`
// Additional OAuth2 client_ids allowed to access the services.
OauthAdditionalClientIds []string `` /* 130-byte string literal not displayed */
// All groups.
Groups []*AuthGroup `protobuf:"bytes,4,rep,name=groups" json:"groups,omitempty"`
// All IP whitelists.
IpWhitelists []*AuthIPWhitelist `protobuf:"bytes,6,rep,name=ip_whitelists,json=ipWhitelists" json:"ip_whitelists,omitempty"`
// Mapping 'account -> IP whitlist to use for that account'.
IpWhitelistAssignments []*AuthIPWhitelistAssignment `protobuf:"bytes,7,rep,name=ip_whitelist_assignments,json=ipWhitelistAssignments" json:"ip_whitelist_assignments,omitempty"`
// URL of a token server to use to generate delegation tokens.
TokenServerUrl *string `protobuf:"bytes,8,opt,name=token_server_url,json=tokenServerUrl" json:"token_server_url,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
An entire database of auth configuration that is being replicated.
func (*AuthDB) GetIpWhitelistAssignments ¶
func (m *AuthDB) GetIpWhitelistAssignments() []*AuthIPWhitelistAssignment
func (*AuthDB) GetIpWhitelists ¶
func (m *AuthDB) GetIpWhitelists() []*AuthIPWhitelist
func (*AuthDB) GetOauthAdditionalClientIds ¶
type AuthDBRevision ¶
type AuthDBRevision struct {
// GAE App ID of a service holding primary copy of Auth DB.
PrimaryId *string `protobuf:"bytes,1,req,name=primary_id,json=primaryId" json:"primary_id,omitempty"`
// Revision of Auth DB being pushed.
AuthDbRev *int64 `protobuf:"varint,2,req,name=auth_db_rev,json=authDbRev" json:"auth_db_rev,omitempty"`
// Timestamp of that revision by Primary's clock, microseconds since epoch.
ModifiedTs *int64 `protobuf:"varint,3,req,name=modified_ts,json=modifiedTs" json:"modified_ts,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Information about some particular revision of auth DB.
func (*AuthDBRevision) Descriptor ¶
func (*AuthDBRevision) Descriptor() ([]byte, []int)
func (*AuthDBRevision) GetAuthDbRev ¶
func (m *AuthDBRevision) GetAuthDbRev() int64
func (*AuthDBRevision) GetModifiedTs ¶
func (m *AuthDBRevision) GetModifiedTs() int64
func (*AuthDBRevision) GetPrimaryId ¶
func (m *AuthDBRevision) GetPrimaryId() string
func (*AuthDBRevision) ProtoMessage ¶
func (*AuthDBRevision) ProtoMessage()
func (*AuthDBRevision) Reset ¶
func (m *AuthDBRevision) Reset()
func (*AuthDBRevision) String ¶
func (m *AuthDBRevision) String() string
type AuthGroup ¶
type AuthGroup struct {
// Name of the group.
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
// List of members that are explicitly in this group.
Members []string `protobuf:"bytes,2,rep,name=members" json:"members,omitempty"`
// List of identity-glob expressions (like 'user:*@example.com').
Globs []string `protobuf:"bytes,3,rep,name=globs" json:"globs,omitempty"`
// List of nested group names.
Nested []string `protobuf:"bytes,4,rep,name=nested" json:"nested,omitempty"`
// Human readable description.
Description *string `protobuf:"bytes,5,req,name=description" json:"description,omitempty"`
// When the group was created. Microseconds since epoch.
CreatedTs *int64 `protobuf:"varint,6,req,name=created_ts,json=createdTs" json:"created_ts,omitempty"`
// Who created the group.
CreatedBy *string `protobuf:"bytes,7,req,name=created_by,json=createdBy" json:"created_by,omitempty"`
// When the group was modified last time. Microseconds since epoch.
ModifiedTs *int64 `protobuf:"varint,8,req,name=modified_ts,json=modifiedTs" json:"modified_ts,omitempty"`
// Who modified the group last time.
ModifiedBy *string `protobuf:"bytes,9,req,name=modified_by,json=modifiedBy" json:"modified_by,omitempty"`
// A name of the group that can modify or delete this group.
Owners *string `protobuf:"bytes,10,opt,name=owners" json:"owners,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Some user group. Corresponds to AuthGroup entity in model.py.
type AuthIPWhitelist ¶
type AuthIPWhitelist struct {
// Name of the IP whitelist.
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
// The list of IP subnets.
Subnets []string `protobuf:"bytes,2,rep,name=subnets" json:"subnets,omitempty"`
// Human readable description.
Description *string `protobuf:"bytes,3,req,name=description" json:"description,omitempty"`
// When the list was created. Microseconds since epoch.
CreatedTs *int64 `protobuf:"varint,4,req,name=created_ts,json=createdTs" json:"created_ts,omitempty"`
// Who created the list.
CreatedBy *string `protobuf:"bytes,5,req,name=created_by,json=createdBy" json:"created_by,omitempty"`
// When the list was modified. Microseconds since epoch.
ModifiedTs *int64 `protobuf:"varint,6,req,name=modified_ts,json=modifiedTs" json:"modified_ts,omitempty"`
// Who modified the list the last time.
ModifiedBy *string `protobuf:"bytes,7,req,name=modified_by,json=modifiedBy" json:"modified_by,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
A named set of whitelisted IP addresses. Corresponds to AuthIPWhitelist entity in model.py.
func (*AuthIPWhitelist) Descriptor ¶
func (*AuthIPWhitelist) Descriptor() ([]byte, []int)
func (*AuthIPWhitelist) GetCreatedBy ¶
func (m *AuthIPWhitelist) GetCreatedBy() string
func (*AuthIPWhitelist) GetCreatedTs ¶
func (m *AuthIPWhitelist) GetCreatedTs() int64
func (*AuthIPWhitelist) GetDescription ¶
func (m *AuthIPWhitelist) GetDescription() string
func (*AuthIPWhitelist) GetModifiedBy ¶
func (m *AuthIPWhitelist) GetModifiedBy() string
func (*AuthIPWhitelist) GetModifiedTs ¶
func (m *AuthIPWhitelist) GetModifiedTs() int64
func (*AuthIPWhitelist) GetName ¶
func (m *AuthIPWhitelist) GetName() string
func (*AuthIPWhitelist) GetSubnets ¶
func (m *AuthIPWhitelist) GetSubnets() []string
func (*AuthIPWhitelist) ProtoMessage ¶
func (*AuthIPWhitelist) ProtoMessage()
func (*AuthIPWhitelist) Reset ¶
func (m *AuthIPWhitelist) Reset()
func (*AuthIPWhitelist) String ¶
func (m *AuthIPWhitelist) String() string
type AuthIPWhitelistAssignment ¶
type AuthIPWhitelistAssignment struct {
// Identity name to limit by IP whitelist.
Identity *string `protobuf:"bytes,1,req,name=identity" json:"identity,omitempty"`
// Name of IP whitelist to use (see AuthIPWhitelist).
IpWhitelist *string `protobuf:"bytes,2,req,name=ip_whitelist,json=ipWhitelist" json:"ip_whitelist,omitempty"`
// Why the assignment was created.
Comment *string `protobuf:"bytes,3,req,name=comment" json:"comment,omitempty"`
// When the assignment was created. Microseconds since epoch.
CreatedTs *int64 `protobuf:"varint,4,req,name=created_ts,json=createdTs" json:"created_ts,omitempty"`
// Who created the assignment.
CreatedBy *string `protobuf:"bytes,5,req,name=created_by,json=createdBy" json:"created_by,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
A pair (identity, IP whitelist name) plus some metadata. Corresponds to AuthIPWhitelistAssignments.Assignment model in model.py.
func (*AuthIPWhitelistAssignment) Descriptor ¶
func (*AuthIPWhitelistAssignment) Descriptor() ([]byte, []int)
func (*AuthIPWhitelistAssignment) GetComment ¶
func (m *AuthIPWhitelistAssignment) GetComment() string
func (*AuthIPWhitelistAssignment) GetCreatedBy ¶
func (m *AuthIPWhitelistAssignment) GetCreatedBy() string
func (*AuthIPWhitelistAssignment) GetCreatedTs ¶
func (m *AuthIPWhitelistAssignment) GetCreatedTs() int64
func (*AuthIPWhitelistAssignment) GetIdentity ¶
func (m *AuthIPWhitelistAssignment) GetIdentity() string
func (*AuthIPWhitelistAssignment) GetIpWhitelist ¶
func (m *AuthIPWhitelistAssignment) GetIpWhitelist() string
func (*AuthIPWhitelistAssignment) ProtoMessage ¶
func (*AuthIPWhitelistAssignment) ProtoMessage()
func (*AuthIPWhitelistAssignment) Reset ¶
func (m *AuthIPWhitelistAssignment) Reset()
func (*AuthIPWhitelistAssignment) String ¶
func (m *AuthIPWhitelistAssignment) String() string
type ChangeNotification ¶
type ChangeNotification struct {
// New revision of the AuthDB.
Revision *AuthDBRevision `protobuf:"bytes,1,opt,name=revision" json:"revision,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Published by Primary into 'auth-db-changed' PubSub topic. The body of the message is base64 encoded serialized ChangeNotification. Additional attributes are:
X-AuthDB-SigKey-v1: <id of a public key> X-AuthDB-SigVal-v1: <base64 encoded RSA-SHA256(blob) signature>
func (*ChangeNotification) Descriptor ¶
func (*ChangeNotification) Descriptor() ([]byte, []int)
func (*ChangeNotification) GetRevision ¶
func (m *ChangeNotification) GetRevision() *AuthDBRevision
func (*ChangeNotification) ProtoMessage ¶
func (*ChangeNotification) ProtoMessage()
func (*ChangeNotification) Reset ¶
func (m *ChangeNotification) Reset()
func (*ChangeNotification) String ¶
func (m *ChangeNotification) String() string
type ReplicationPushRequest ¶
type ReplicationPushRequest struct {
// Revision that is being pushed.
Revision *AuthDBRevision `protobuf:"bytes,1,opt,name=revision" json:"revision,omitempty"`
// An entire database of auth configuration for specific revision.
AuthDb *AuthDB `protobuf:"bytes,2,opt,name=auth_db,json=authDb" json:"auth_db,omitempty"`
// Version of 'auth' component on Primary, see components/auth/version.py.
AuthCodeVersion *string `protobuf:"bytes,3,opt,name=auth_code_version,json=authCodeVersion" json:"auth_code_version,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Sent from Primary to Replica to update Replica's AuthDB. Primary signs the entire serialized message with its private key and appends two headers to HTTP request that carries the blob:
X-AuthDB-SigKey-v1: <id of a public key> X-AuthDB-SigVal-v1: <base64 encoded RSA-SHA256(SHA512(blob)) signature>
func (*ReplicationPushRequest) Descriptor ¶
func (*ReplicationPushRequest) Descriptor() ([]byte, []int)
func (*ReplicationPushRequest) GetAuthCodeVersion ¶
func (m *ReplicationPushRequest) GetAuthCodeVersion() string
func (*ReplicationPushRequest) GetAuthDb ¶
func (m *ReplicationPushRequest) GetAuthDb() *AuthDB
func (*ReplicationPushRequest) GetRevision ¶
func (m *ReplicationPushRequest) GetRevision() *AuthDBRevision
func (*ReplicationPushRequest) ProtoMessage ¶
func (*ReplicationPushRequest) ProtoMessage()
func (*ReplicationPushRequest) Reset ¶
func (m *ReplicationPushRequest) Reset()
func (*ReplicationPushRequest) String ¶
func (m *ReplicationPushRequest) String() string
type ReplicationPushResponse ¶
type ReplicationPushResponse struct {
// Overall status of the operation.
Status *ReplicationPushResponse_Status `protobuf:"varint,1,req,name=status,enum=protocol.ReplicationPushResponse_Status" json:"status,omitempty"`
// Revision known by Replica (set for APPLIED and SKIPPED statuses).
CurrentRevision *AuthDBRevision `protobuf:"bytes,2,opt,name=current_revision,json=currentRevision" json:"current_revision,omitempty"`
// Present for TRANSIENT_ERROR and FATAL_ERROR statuses.
ErrorCode *ReplicationPushResponse_ErrorCode `` /* 130-byte string literal not displayed */
// Version of 'auth' component on Replica, see components/auth/version.py.
AuthCodeVersion *string `protobuf:"bytes,4,opt,name=auth_code_version,json=authCodeVersion" json:"auth_code_version,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Replica's response to ReplicationPushRequest.
func (*ReplicationPushResponse) Descriptor ¶
func (*ReplicationPushResponse) Descriptor() ([]byte, []int)
func (*ReplicationPushResponse) GetAuthCodeVersion ¶
func (m *ReplicationPushResponse) GetAuthCodeVersion() string
func (*ReplicationPushResponse) GetCurrentRevision ¶
func (m *ReplicationPushResponse) GetCurrentRevision() *AuthDBRevision
func (*ReplicationPushResponse) GetErrorCode ¶
func (m *ReplicationPushResponse) GetErrorCode() ReplicationPushResponse_ErrorCode
func (*ReplicationPushResponse) GetStatus ¶
func (m *ReplicationPushResponse) GetStatus() ReplicationPushResponse_Status
func (*ReplicationPushResponse) ProtoMessage ¶
func (*ReplicationPushResponse) ProtoMessage()
func (*ReplicationPushResponse) Reset ¶
func (m *ReplicationPushResponse) Reset()
func (*ReplicationPushResponse) String ¶
func (m *ReplicationPushResponse) String() string
type ReplicationPushResponse_ErrorCode ¶
type ReplicationPushResponse_ErrorCode int32
Error codes, for TRANSIENT_ERROR and FATAL_ERROR statuses.
const ( // Trying to push an update to service that is not a replica. ReplicationPushResponse_NOT_A_REPLICA ReplicationPushResponse_ErrorCode = 1 // Replica doesn't know about the service that pushing the update. ReplicationPushResponse_FORBIDDEN ReplicationPushResponse_ErrorCode = 2 // Signature headers are missing. ReplicationPushResponse_MISSING_SIGNATURE ReplicationPushResponse_ErrorCode = 3 // Signature is not valid. ReplicationPushResponse_BAD_SIGNATURE ReplicationPushResponse_ErrorCode = 4 // Format of the request is not valid. ReplicationPushResponse_BAD_REQUEST ReplicationPushResponse_ErrorCode = 5 )
func (ReplicationPushResponse_ErrorCode) Enum ¶
func (x ReplicationPushResponse_ErrorCode) Enum() *ReplicationPushResponse_ErrorCode
func (ReplicationPushResponse_ErrorCode) EnumDescriptor ¶
func (ReplicationPushResponse_ErrorCode) EnumDescriptor() ([]byte, []int)
func (ReplicationPushResponse_ErrorCode) String ¶
func (x ReplicationPushResponse_ErrorCode) String() string
func (*ReplicationPushResponse_ErrorCode) UnmarshalJSON ¶
func (x *ReplicationPushResponse_ErrorCode) UnmarshalJSON(data []byte) error
type ReplicationPushResponse_Status ¶
type ReplicationPushResponse_Status int32
Overall status of the operation.
const ( // Replica accepted the push request and updated its copy of auth db. ReplicationPushResponse_APPLIED ReplicationPushResponse_Status = 0 // Replica has a newer version of AuthDB, the push request is skipped. ReplicationPushResponse_SKIPPED ReplicationPushResponse_Status = 1 // Non fatal error happened, the push request may be retried. ReplicationPushResponse_TRANSIENT_ERROR ReplicationPushResponse_Status = 2 // Fatal error happened, the push request must not be retried. ReplicationPushResponse_FATAL_ERROR ReplicationPushResponse_Status = 3 )
func (ReplicationPushResponse_Status) Enum ¶
func (x ReplicationPushResponse_Status) Enum() *ReplicationPushResponse_Status
func (ReplicationPushResponse_Status) EnumDescriptor ¶
func (ReplicationPushResponse_Status) EnumDescriptor() ([]byte, []int)
func (ReplicationPushResponse_Status) String ¶
func (x ReplicationPushResponse_Status) String() string
func (*ReplicationPushResponse_Status) UnmarshalJSON ¶
func (x *ReplicationPushResponse_Status) UnmarshalJSON(data []byte) error
type ServiceLinkRequest ¶
type ServiceLinkRequest struct {
// Same ticket that was passed to Replica via ServiceLinkTicket.
Ticket []byte `protobuf:"bytes,1,req,name=ticket" json:"ticket,omitempty"`
// URL to use when making requests to Replica from Primary.
ReplicaUrl *string `protobuf:"bytes,2,req,name=replica_url,json=replicaUrl" json:"replica_url,omitempty"`
// Identity of a user that accepted the ticket and initiated this request.
InitiatedBy *string `protobuf:"bytes,3,req,name=initiated_by,json=initiatedBy" json:"initiated_by,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Sent from Replica to Primary via direct serivce <-> service HTTP call, replicas app_id would be available via X-Appengine-Inbound-Appid header.
func (*ServiceLinkRequest) Descriptor ¶
func (*ServiceLinkRequest) Descriptor() ([]byte, []int)
func (*ServiceLinkRequest) GetInitiatedBy ¶
func (m *ServiceLinkRequest) GetInitiatedBy() string
func (*ServiceLinkRequest) GetReplicaUrl ¶
func (m *ServiceLinkRequest) GetReplicaUrl() string
func (*ServiceLinkRequest) GetTicket ¶
func (m *ServiceLinkRequest) GetTicket() []byte
func (*ServiceLinkRequest) ProtoMessage ¶
func (*ServiceLinkRequest) ProtoMessage()
func (*ServiceLinkRequest) Reset ¶
func (m *ServiceLinkRequest) Reset()
func (*ServiceLinkRequest) String ¶
func (m *ServiceLinkRequest) String() string
type ServiceLinkResponse ¶
type ServiceLinkResponse struct {
Status *ServiceLinkResponse_Status `protobuf:"varint,1,req,name=status,enum=protocol.ServiceLinkResponse_Status" json:"status,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Primary's response to ServiceLinkRequest. Always returned with HTTP code 200.
func (*ServiceLinkResponse) Descriptor ¶
func (*ServiceLinkResponse) Descriptor() ([]byte, []int)
func (*ServiceLinkResponse) GetStatus ¶
func (m *ServiceLinkResponse) GetStatus() ServiceLinkResponse_Status
func (*ServiceLinkResponse) ProtoMessage ¶
func (*ServiceLinkResponse) ProtoMessage()
func (*ServiceLinkResponse) Reset ¶
func (m *ServiceLinkResponse) Reset()
func (*ServiceLinkResponse) String ¶
func (m *ServiceLinkResponse) String() string
type ServiceLinkResponse_Status ¶
type ServiceLinkResponse_Status int32
Status codes.
const ( // The service is now linked and primary will be pushing updates to it. ServiceLinkResponse_SUCCESS ServiceLinkResponse_Status = 0 // Primary do not replies. ServiceLinkResponse_TRANSPORT_ERROR ServiceLinkResponse_Status = 1 // Linking ticket is invalid or expired. ServiceLinkResponse_BAD_TICKET ServiceLinkResponse_Status = 2 // Linking ticket was generated for another app, not the calling one. ServiceLinkResponse_AUTH_ERROR ServiceLinkResponse_Status = 3 )
func (ServiceLinkResponse_Status) Enum ¶
func (x ServiceLinkResponse_Status) Enum() *ServiceLinkResponse_Status
func (ServiceLinkResponse_Status) EnumDescriptor ¶
func (ServiceLinkResponse_Status) EnumDescriptor() ([]byte, []int)
func (ServiceLinkResponse_Status) String ¶
func (x ServiceLinkResponse_Status) String() string
func (*ServiceLinkResponse_Status) UnmarshalJSON ¶
func (x *ServiceLinkResponse_Status) UnmarshalJSON(data []byte) error
type ServiceLinkTicket ¶
type ServiceLinkTicket struct {
// GAE application ID of Primary that generated this ticket. Replica will send
// ServiceLinkRequest to this service when it processes the ticket.
PrimaryId *string `protobuf:"bytes,1,req,name=primary_id,json=primaryId" json:"primary_id,omitempty"`
// URL to the root page of a primary service, i.e. https://<...>.appspot.com.
// Useful when testing on dev appserver and on non-default version.
PrimaryUrl *string `protobuf:"bytes,2,req,name=primary_url,json=primaryUrl" json:"primary_url,omitempty"`
// Identity of a user that generated this ticket.
GeneratedBy *string `protobuf:"bytes,3,req,name=generated_by,json=generatedBy" json:"generated_by,omitempty"`
// Opaque blob passed back to Primary in ServiceLinkRequest. Its exact
// structure is an implementation detail of Primary. It contains app_id of
// a replica this ticket is intended for, timestamp and HMAC tag.
Ticket []byte `protobuf:"bytes,4,req,name=ticket" json:"ticket,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Generated by Primary, passed to Replica to initiate linking process.
func (*ServiceLinkTicket) Descriptor ¶
func (*ServiceLinkTicket) Descriptor() ([]byte, []int)
func (*ServiceLinkTicket) GetGeneratedBy ¶
func (m *ServiceLinkTicket) GetGeneratedBy() string
func (*ServiceLinkTicket) GetPrimaryId ¶
func (m *ServiceLinkTicket) GetPrimaryId() string
func (*ServiceLinkTicket) GetPrimaryUrl ¶
func (m *ServiceLinkTicket) GetPrimaryUrl() string
func (*ServiceLinkTicket) GetTicket ¶
func (m *ServiceLinkTicket) GetTicket() []byte
func (*ServiceLinkTicket) ProtoMessage ¶
func (*ServiceLinkTicket) ProtoMessage()
func (*ServiceLinkTicket) Reset ¶
func (m *ServiceLinkTicket) Reset()
func (*ServiceLinkTicket) String ¶
func (m *ServiceLinkTicket) String() string
Source Files
¶
- generate.go
- replication.pb.go